assert_reachable_gated

Macro assert_reachable_gated 

macro_rules! assert_reachable_gated {
    ($message:literal, $expected_reachable:expr) => { ... };
}
Like mysten_common::assert_reachable!, but only expected to be reached under protocol configs satisfying $expected_reachable. See the module docs.

The predicate must be a non-capturing closure over &ProtocolConfig that does not panic for any supported configuration; it runs during epoch-store construction.